pub enum CreateServiceError {
AccessDenied(String),
Client(String),
ClusterNotFound(String),
InvalidParameter(String),
PlatformTaskDefinitionIncompatibility(String),
PlatformUnknown(String),
Server(String),
UnsupportedFeature(String),
}Expand description
Errors returned by CreateService
Variants
AccessDenied(String)
You do not have authorization to perform the requested action.
Client(String)
These errors are usually caused by a client action, such as using an action or resource on behalf of a user that doesn't have permissions to use the action or resource, or specifying an identifier that is not valid.
ClusterNotFound(String)
The specified cluster could not be found. You can view your available clusters with ListClusters. Amazon ECS clusters are Region-specific.
InvalidParameter(String)
The specified parameter is invalid. Review the available parameters for the API request.
PlatformTaskDefinitionIncompatibility(String)
The specified platform version does not satisfy the task definition's required capabilities.
PlatformUnknown(String)
The specified platform version does not exist.
Server(String)
These errors are usually caused by a server issue.
UnsupportedFeature(String)
The specified task is not supported in this Region.
Implementations
Sourceimpl CreateServiceError
impl CreateServiceError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<CreateServiceError>