pub enum DeleteTaskSetError {
AccessDenied(String),
Client(String),
ClusterNotFound(String),
InvalidParameter(String),
Server(String),
ServiceNotActive(String),
ServiceNotFound(String),
TaskSetNotFound(String),
UnsupportedFeature(String),
}Expand description
Errors returned by DeleteTaskSet
Variants
AccessDenied(String)
You do not have authorization to perform the requested action.
Client(String)
These errors are usually caused by a client action, such as using an action or resource on behalf of a user that doesn't have permissions to use the action or resource, or specifying an identifier that is not valid.
ClusterNotFound(String)
The specified cluster could not be found. You can view your available clusters with ListClusters. Amazon ECS clusters are Region-specific.
InvalidParameter(String)
The specified parameter is invalid. Review the available parameters for the API request.
Server(String)
These errors are usually caused by a server issue.
ServiceNotActive(String)
The specified service is not active. You can't update a service that is inactive. If you have previously deleted a service, you can re-create it with CreateService.
ServiceNotFound(String)
The specified service could not be found. You can view your available services with ListServices. Amazon ECS services are cluster-specific and Region-specific.
TaskSetNotFound(String)
The specified task set could not be found. You can view your available task sets with DescribeTaskSets. Task sets are specific to each cluster, service and Region.
UnsupportedFeature(String)
The specified task is not supported in this Region.
Implementations
Sourceimpl DeleteTaskSetError
impl DeleteTaskSetError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<DeleteTaskSetError>